# -*- coding: utf-8 -*-

from scrobbles.models import Artist, Scrobble, ArtistName, TrackName
from scrobbles.models import Track
from django.contrib import admin

class ArtistAdmin(admin.ModelAdmin):
    list_display = ('name', 'scid', 'is_mbid')
    list_per_page = 30
    list_filter = ('is_mbid',)
    search_fields = ['artistname__name']
    actions = ['merges_ids']

    def merges_ids(self, request, queryset):
        if len(queryset) < 2:
            message_bit = u'Can merge at least 2 entries!'
            self.message_user(request, message_bit)
            return
        #  Merges on MBID artist if possible
        try:
            art_to_merge_to = queryset.get(is_mbid=True)
        except Artist.DoesNotExist:
            art_to_merge_to = queryset[0]
        message_bit = u'Merged into %s (%s)' % (art_to_merge_to,art_to_merge_to.scid)
        for art in queryset:
            if art == art_to_merge_to:
                continue
            ArtistName.objects.filter(artist=art).update(artist=art_to_merge_to)
            Track.objects.filter(artist=art).update(artist=art_to_merge_to)
            art.delete()
        self.message_user(request, message_bit)
        tracks_name = set(
                [trk.name for trk
                 in TrackName.objects.filter(track__artist=art_to_merge_to)
                ])  #  unik trackname list
        for title in tracks_name:
            try:
                TrackName.objects.get(name=title, track__artist=art_to_merge_to)
            except TrackName.MultipleObjectsReturned:
                self.message_user(request, 'Track "%s" needs to be merged' % title)
                dupes = Track.objects.filter(trackname__name=title, artist=art_to_merge_to)
                for dupe in dupes[1:]:
                    Scrobble.objects.filter(track=dupe).update(track=dupes[0])
                    TrackName.objects.get(track=dupe).delete()
                    dupe.delete()


class TrackAdmin(admin.ModelAdmin):
    list_display = ('get_name', 'artist')
    list_filter = ['artist']
    list_per_page = 30


class ScrobbleAdmin(admin.ModelAdmin):
    list_display = ('date', 'user', 'track')
    list_filter = ['date', 'user']
    list_per_page = 30
    date_hierarchy = 'date'
    ordering = ['-date']


admin.site.register(Artist, ArtistAdmin)
admin.site.register(Track, TrackAdmin)
admin.site.register(Scrobble, ScrobbleAdmin)


# vim: ai ts=4 sw=4 sts=4 expandtab

